@@ -1,6 +1,5 @@
-from pytest import Session
 from sqlalchemy import create_engine, false
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, Session
 from .base import Base
 
 
