@@ -1,6 +1,6 @@
 import pathlib, os
 import string, random
-
+from pathlib import Path
 
 def check_internet(host="8.8.8.8", port=53, timeout=3) -> bool:
     """
@@ -52,8 +52,34 @@ def hookup_tqdm():
 def is_virtualenv():
     return "VIRTUAL_ENV" in os.environ
 
+
 def get_virtualenv_path():
     return os.environ["VIRTUAL_ENV"]
 
+
 def is_root():
     return os.geteuid() == 0
+
+
+def file_replace_string(src: Path, dst: Path, old_string: str, new_string: str):
+    '''creates a new file with all occurrences of old_string replaced by new_string'''
+    # safely read the input filename using 'with'
+    with open(src) as f:
+        s = f.read()
+        if old_string not in s:
+            raise Exception('"{old_string}" not found in {filename}.'.format(**locals()))
+
+    # safely write the changed content, if found in the file
+    with open(dst, 'w') as f:
+        s = s.replace(old_string, new_string)
+        f.write(s)
+
+
+def is_systemd_installed() -> bool:
+    result = os.popen('test -x /run/systemd/system && echo "systemd" || echo "other"').read()
+    return 'systemd' in result
+
+
+def is_systemd_service_running(name: str) -> bool:
+    status = os.system(f'systemctl is-active --quiet {name}')
+    return status == 0
